@@ -12,24 +12,29 @@ use warnings;
 
 package Dist::Zilla::Plugin::Git::Check;
 {
-  $Dist::Zilla::Plugin::Git::Check::VERSION = '1.122530';
+  $Dist::Zilla::Plugin::Git::Check::VERSION = '1.122770';
 }
 # ABSTRACT: check your git repository before releasing
 
-use Git::Wrapper;
 use Moose;
+use namespace::autoclean 0.09;
+use Moose::Util::TypeConstraints qw(enum);
+
+enum('DieWarnIgnore', [qw[ die warn ignore ]]);
 
 with 'Dist::Zilla::Role::BeforeRelease';
 with 'Dist::Zilla::Role::Git::Repo';
 with 'Dist::Zilla::Role::Git::DirtyFiles';
 
+has untracked_files => ( is=>'ro', isa=>'DieWarnIgnore', default => 'die' );
 
 # -- public methods
 
 sub before_release {
     my $self = shift;
 
-    my $git = Git::Wrapper->new( $self->repo_root );
+    my @issues;
+    my $git = $self->git;
     my @output;
 
     # fetch current branch
@@ -59,13 +64,24 @@ sub before_release {
     # no files should be untracked
     @output = $git->ls_files( { others=>1, 'exclude-standard'=>1 } );
     if ( @output ) {
+      push @issues, @output . " untracked file" . (@output == 1 ? '' : 's');
+
+      my $untracked = $self->untracked_files;
+      if ($untracked ne 'ignore') {
+        my $log_method = ($untracked eq 'die') ? 'log_fatal' : 'log';
+
         my $errmsg =
             "branch $branch has some untracked files:\n" .
-            join "\n", map { "\t$_" } @output;
-        $self->log_fatal($errmsg);
+                join "\n", map { "\t$_" } @output;
+        $self->$log_method($errmsg);
+      }
     }
 
-    $self->log( "branch $branch is in a clean state" );
+    if (@issues) {
+      $self->log( "branch $branch has " . join(', ', @issues));
+    } else {
+      $self->log( "branch $branch is in a clean state" );
+    }
 }
 
 
@@ -81,7 +97,7 @@ Dist::Zilla::Plugin::Git::Check - check your git repository before releasing
 
 =head1 VERSION
 
-version 1.122530
+version 1.122770
 
 =head1 SYNOPSIS
 
@@ -91,6 +107,7 @@ In your F<dist.ini>:
     allow_dirty = dist.ini
     allow_dirty = README
     changelog = Changes      ; this is the default
+    untracked_files = die    ; default value (can also be "warn" or "ignore")
 
 =head1 DESCRIPTION
 
@@ -122,6 +139,11 @@ modifications.  This option may appear multiple times.  The default
 list is F<dist.ini> and the changelog file given by C<changelog>.  You
 can use C<allow_dirty => to prohibit all local modifications.
 
+=item * untracked_files - indicates what to do if there are untracked
+files.  Must be either C<die> (the default), C<warn>, or C<ignore>.
+C<warn> lists the untracked files, while C<ignore> only prints the
+total number of untracked files.
+
 =back
 
 =for Pod::Coverage before_release
