@@ -12,12 +12,11 @@ use warnings;
 
 package Dist::Zilla::Plugin::Git::Commit;
 {
-  $Dist::Zilla::Plugin::Git::Commit::VERSION = '1.122530';
+  $Dist::Zilla::Plugin::Git::Commit::VERSION = '1.122770';
 }
 # ABSTRACT: commit dirty files
 
 use File::Temp           qw{ tempfile };
-use Git::Wrapper;
 use Moose;
 use MooseX::Has::Sugar;
 use MooseX::Types::Moose qw{ Str };
@@ -56,7 +55,7 @@ sub mvp_multivalue_args { qw( add_files_in ) }
 sub after_release {
     my $self = shift;
 
-    my $git  = Git::Wrapper->new( $self->repo_root );
+    my $git  = $self->git;
     my @output;
 
     # check if there are dirty files that need to be committed.
@@ -132,7 +131,7 @@ Dist::Zilla::Plugin::Git::Commit - commit dirty files
 
 =head1 VERSION
 
-version 1.122530
+version 1.122770
 
 =head1 SYNOPSIS
 
