@@ -12,11 +12,10 @@ use warnings;
 
 package Dist::Zilla::Plugin::Git::Tag;
 {
-  $Dist::Zilla::Plugin::Git::Tag::VERSION = '1.122530';
+  $Dist::Zilla::Plugin::Git::Tag::VERSION = '1.122770';
 }
 # ABSTRACT: tag the new version
 
-use Git::Wrapper;
 use Moose;
 use MooseX::Has::Sugar;
 use MooseX::Types::Moose qw{ Str };
@@ -62,17 +61,14 @@ sub _build_tag
 sub before_release {
     my $self = shift;
 
-    my $git  = Git::Wrapper->new( $self->repo_root );
-
     # Make sure a tag with the new version doesn't exist yet:
     my $tag = $self->tag;
     $self->log_fatal("tag $tag already exists")
-        if $git->tag('-l', $tag );
+        if $self->git->tag('-l', $tag );
 }
 
 sub after_release {
     my $self = shift;
-    my $git  = Git::Wrapper->new( $self->repo_root );
 
     my @opts;
     push @opts, ( '-m' => _format_tag($self->tag_message, $self) )
@@ -84,7 +80,7 @@ sub after_release {
 
     # create a tag with the new version
     my $tag = $self->tag;
-    $git->tag( @opts, $tag, @branch );
+    $self->git->tag( @opts, $tag, @branch );
     $self->log("Tagged $tag");
 }
 
@@ -100,7 +96,7 @@ Dist::Zilla::Plugin::Git::Tag - tag the new version
 
 =head1 VERSION
 
-version 1.122530
+version 1.122770
 
 =head1 SYNOPSIS
 
