@@ -8,16 +8,25 @@
 #
 package Dist::Zilla::Role::Git::Repo;
 {
-  $Dist::Zilla::Role::Git::Repo::VERSION = '1.122530';
+  $Dist::Zilla::Role::Git::Repo::VERSION = '1.122770';
 }
 
 # ABSTRACT: Provide repository information for Git plugins
 
 use Moose::Role;
+use Git::Wrapper ();
 
 has 'repo_root'   => ( is => 'ro', isa => 'Str', default => '.' );
 
 
+my %cached_wrapper;
+
+sub git {
+  my $root = shift->repo_root;
+
+  $cached_wrapper{$root} ||= Git::Wrapper->new( $root );
+}
+
 1;
 
 __END__
@@ -30,11 +39,12 @@ Dist::Zilla::Role::Git::Repo - Provide repository information for Git plugins
 
 =head1 VERSION
 
-version 1.122530
+version 1.122770
 
 =head1 DESCRIPTION
 
-This role is used within the git plugin to get information about the repository structure.
+This role is used within the Git plugins to get information about the
+repository structure, and to create a Git::Wrapper object.
 
 =head1 ATTRIBUTES
 
@@ -42,6 +52,17 @@ This role is used within the git plugin to get information about the repository
 
 The repository root, either as a full path or relative to the distribution root. Default is C<.>.
 
+=head1 METHODS
+
+=head2 git
+
+  $git = $plugin->git;
+
+This method returns a Git::Wrapper object for the C<repo_root>
+directory, constructing one if necessary.  The object is shared
+between all plugins that consume this role (if they have the same
+C<repo_root>).
+
 =head1 AUTHOR
 
 Jerome Quelin
